Optional Settings — django-frontend-skeleton 0.7.1 documentation

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 0.7.1 documentation »

# Optional Settings

There are now optional settings for customizing Google Analytics tracking code.

## H5BP_GA_SETDOMAINNAME

Set domain for multiple, or cross-domain tracking.

## H5BP_GA_SETALLOWLINKER

To use _setAllowLinker method on target site for cross-domain tracking. Set to ‘True’ to enable. Requires H5BP_GA_SETDOMAINNAME to be set.

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 0.7.1 documentation »